@@ -118,7 +118,7 @@ URL_MAPPINGS = {
     "KNMI": "http://rdsa.knmi.nl",
     "KOERI": "http://eida.koeri.boun.edu.tr",
     "LMU": "http://erde.geophysik.uni-muenchen.de",
-    "NCEDC": "http://service.ncedc.org",
+    "NCEDC": "https://service.ncedc.org",
     "NIEP": "http://eida-sc3.infp.ro",
     "NOA": "http://eida.gein.noa.gr",
     "ODC": "http://www.orfeus-eu.org",
