@@ -23,11 +23,3 @@ class SLStateTestCase(unittest.TestCase):
 
         self.assertNotEqual(id(slstate1.databuf), id(slstate2.databuf))
         self.assertNotEqual(id(slstate1.packed_buf), id(slstate2.packed_buf))
-
-
-def suite():
-    return unittest.makeSuite(SLStateTestCase, 'test')
-
-
-if __name__ == '__main__':
-    unittest.main(defaultTest='suite')
