@@ -6,6 +6,7 @@ import os
 import re
 import unittest
 import warnings
+from pathlib import Path
 
 from obspy import UTCDateTime, read_events
 from obspy.core.inventory import Inventory, Network, Station, Channel
@@ -37,9 +38,9 @@ class NLLOCTestCase(unittest.TestCase):
     Test suite for obspy.io.nlloc
     """
     def setUp(self):
-        self.path = os.path.dirname(os.path.abspath(inspect.getfile(
-            inspect.currentframe())))
-        self.datapath = os.path.join(self.path, "data")
+        self.path = Path(os.path.dirname(os.path.abspath(inspect.getfile(
+            inspect.currentframe()))))
+        self.datapath = self.path / "data"
 
     def test_write_nlloc_obs(self):
         """
@@ -196,8 +197,8 @@ class NLLOCTestCase(unittest.TestCase):
             self.assertEqual(arriv.phase, arriv_expected.phase)
             self.assertAlmostEqual(arriv.azimuth, arriv_expected.azimuth)
             self.assertAlmostEqual(arriv.distance, arriv_expected.distance)
-            self.assertAlmostEqual(arriv.takeoff_angle,
-                                   arriv_expected.takeoff_angle)
+            assert arriv.takeoff_angle is None
+            assert arriv_expected.takeoff_angle is None
             self.assertAlmostEqual(arriv.time_residual,
                                    arriv_expected.time_residual)
             self.assertAlmostEqual(arriv.time_weight,
@@ -338,10 +339,12 @@ class NLLOCTestCase(unittest.TestCase):
         self.assertEqual(pick1.time.hour, 0)
         self.assertEqual(pick2.time.second, 0)
 
-
-def suite():
-    return unittest.makeSuite(NLLOCTestCase, "test")
-
-
-if __name__ == "__main__":
-    unittest.main(defaultTest="suite")
+    def test_reading_nlloc_v7_hyp_file(self):
+        """
+        Tests that we are getting the positioning of items in phase lines
+        right. Values for arrivals are shifted by one index to the right in hyp
+        files written by newer nonlinloc versions, see #3223
+        """
+        path = str(self.datapath / 'nlloc_v7.hyp')
+        cat = read_nlloc_hyp(path)
+        assert cat[0].origins[0].arrivals[0].azimuth == 107.42
